@@ -342,11 +342,21 @@ pub fn impl_widget_trait(ast: &DeriveInput) -> TokenStream {
         format!("{}_{}", name_str, "visible_r").as_str(),
         name.span(),
     );
+    let active = Ident::new(format!("{}_{}", name_str, "active").as_str(), name.span());
+    let active_r = Ident::new(
+        format!("{}_{}", name_str, "active_r").as_str(),
+        name.span(),
+    );
 
     let gen = quote! {
         unsafe impl Send for #name {}
         unsafe impl Sync for #name {}
-
+        impl PartialEq for #name {
+            fn eq(&self, other: &Self) -> bool {
+                self.inner == other.inner
+            }
+        }
+        impl Eq for #name {}
         impl Clone for #name {
             fn clone(&self) -> #name {
                 assert!(!self.was_deleted());
@@ -1003,6 +1013,24 @@ pub fn impl_widget_trait(ast: &DeriveInput) -> TokenStream {
                     #visible_r(self.inner) != 0
                 }
             }
+
+            fn is_same<W: WidgetExt>(&self, other: &W) -> bool {
+                unsafe { self.as_widget_ptr() == other.as_widget_ptr() }
+            }
+
+            fn active(&self) -> bool {
+                assert!(!self.was_deleted());
+                unsafe {
+                    #active(self.inner) != 0
+                }
+            }
+
+            fn active_r(&self) -> bool {
+                assert!(!self.was_deleted());
+                unsafe {
+                    #active_r(self.inner) != 0
+                }
+            }
         }
     };
     gen.into()
